from __future__ import absolute_import
import quantities as pq


# At least up to quantities 0.10.1 the additional arguments to the min and max
# function did not get passed along.
# A fix already exists:
# <https://github.com/dopplershift/python-quantities/commit/30e8812ac15f551c65311d808c2a004f53913a25>
# Also a pull request exists which has not been merged at the time of writing
# 01/18/2013:
# <https://github.com/python-quantities/python-quantities/pull/41>

def _Quanitity_max(self, axis=None, out=None):
    return pq.Quantity(
        self.magnitude.max(axis, out),
        self.dimensionality,
        copy=False
    )
pq.Quantity.max = _Quanitity_max


def _Quanitity_min(self, axis=None, out=None):
    return pq.Quantity(
        self.magnitude.min(axis, out),
        self.dimensionality,
        copy=False
    )
pq.Quantity.min = _Quanitity_min


# Python quantities does not use have additional parameters for astype()
# which became a problem in linspace in numpy 1.11. This is a dirty, dirty
# hack to allow the Quantity astype function to accept any arguments and work
# with numpy >= 1.11. A bug has been filed at
# <https://github.com/python-quantities/python-quantities/issues/105>
_original_astype = pq.Quantity.astype
def _Quantity_astype(self, dtype=None, *args, **kwargs):
    return _original_astype(self, dtype)
pq.Quantity.astype = _Quantity_astype



try:
    import unittest2 as ut
    assert ut  # Suppress pyflakes warning about redefinition of unused ut
except ImportError:
    import unittest as ut

from builders import arange_spikes
from numpy.testing import assert_array_equal, assert_array_almost_equal
import spykeutils.rate_estimation as re
import neo
import quantities as pq
import scipy as sp


class TestScipyMaximum(ut.TestCase):
    def test_collapse_empty_list(self):
        try:
            re.collapsed_spike_trains([])
        except:
            self.fail('Collapsing an empty list of spike trains should'
                      'not raise an exception')

    def test_density_estimation_empty_list(self):
        try:
            re.spike_density_estimation({1: []})
        except:
            self.fail('Density estimation with an empty list of spike'
                      'trains should not raise an exception')

    def test_psth_empty_list(self):
        try:
            re.psth({1: []}, 100 * pq.ms)
        except:
            self.fail('PSTH with an empty list of spikes should not raise'
                      'an exception')


if __name__ == '__main__':
    ut.main()
